@@ -8,9 +8,26 @@ store_produce_path.tar_aws <- function(store, name, object, path_store) {
   )
 }
 
+#' @export
+store_class_repository.aws <- function(repository, store, format) {
+  format <- gsub(pattern = "\\&.*$", replacement = "", x = format)
+  c(
+    sprintf("tar_aws_%s", format),
+    "tar_aws",
+    "tar_cloud",
+    if_any("tar_external" %in% class(store), character(0), "tar_external"),
+    class(store)
+  )
+}
+
+#' @export
+store_assert_repository_setting.aws <- function(repository) {
+}
+
 store_produce_aws_path <- function(store, name, object, path_store) {
   bucket <- store$resources$aws$bucket %|||% store$resources$bucket
   region <- store$resources$aws$region %|||% store$resources$region
+  endpoint <- store$resources$aws$endpoint %|||% store$resources$endpoint
   tar_assert_nonempty(bucket)
   tar_assert_chr(bucket)
   tar_assert_scalar(bucket)
@@ -18,6 +35,9 @@ store_produce_aws_path <- function(store, name, object, path_store) {
   tar_assert_nonempty(region %|||% "region")
   tar_assert_chr(region %|||% "region")
   tar_assert_scalar(region %|||% "region")
+  tar_assert_nonempty(endpoint %|||% "endpoint")
+  tar_assert_chr(endpoint %|||% "endpoint")
+  tar_assert_scalar(endpoint %|||% "endpoint")
   prefix <- store$resources$aws$prefix %|||%
     store$resources$prefix %|||%
     path_objects_dir_cloud()
@@ -28,8 +48,11 @@ store_produce_aws_path <- function(store, name, object, path_store) {
   tar_assert_nzchar(key)
   bucket <- paste0("bucket=", bucket)
   region <- paste0("region=", if_any(is.null(region), "NULL", region))
+  endpoint <- if_any(is.null(endpoint), "NULL", endpoint)
+  endpoint <- base64url::base64_urlencode(endpoint)
+  endpoint <- paste0("endpoint=", endpoint)
   key <- paste0("key=", key)
-  c(bucket, region, key)
+  c(bucket, region, key, endpoint)
 }
 
 store_aws_bucket <- function(path) {
@@ -44,7 +67,7 @@ store_aws_bucket <- function(path) {
 store_aws_region <- function(path) {
   # compatibility with targets <= 0.8.1:
   if (store_aws_path_0.8.1(path)) {
-    return()
+    return(NULL)
   }
   # with metadata written by targets > 0.8.1:
   out <- store_aws_path_field(path = path, pattern = "^region=")
@@ -52,6 +75,18 @@ store_aws_region <- function(path) {
   if_any(identical(out, "NULL"), NULL, out)
 }
 
+store_aws_endpoint <- function(path) {
+  # compatibility with targets <= 0.8.1:
+  if (store_aws_path_0.8.1(path)) {
+    return(NULL)
+  }
+  # with metadata written by targets > 0.8.1:
+  out <- store_aws_path_field(path = path, pattern = "^endpoint=")
+  out <- if_any(length(out) > 0L && any(nzchar(out)), out, "")
+  out <- base64url::base64_urldecode(out)
+  if_any(identical(out, "NULL"), NULL, out)
+}
+
 store_aws_key <- function(path) {
   # compatibility with targets <= 0.8.1:
   if (store_aws_path_0.8.1(path)) {
@@ -60,16 +95,16 @@ store_aws_key <- function(path) {
   store_aws_path_field(path = path, pattern = "^key=")
 }
 
-store_aws_path_field <- function(path, pattern) {
-  path <- store_aws_split_colon(path)
-  keyvalue_field(x = path, pattern = pattern)
-}
-
 store_aws_version <- function(path) {
   out <- store_aws_path_field(path = path, pattern = "^version=")
   if_any(length(out) && nzchar(out), out, NULL)
 }
 
+store_aws_path_field <- function(path, pattern) {
+  path <- store_aws_split_colon(path)
+  keyvalue_field(x = path, pattern = pattern)
+}
+
 store_aws_path_0.8.1 <- function(path) {
   !any(grepl(pattern = "^bucket=", x = path))
 }
@@ -97,11 +132,53 @@ store_read_object.tar_aws <- function(store) {
     bucket = store_aws_bucket(path),
     file = tmp,
     region = store_aws_region(path),
+    endpoint = store_aws_endpoint(path),
     version = store_aws_version(path)
   )
   store_convert_object(store, store_read_path(store, tmp))
 }
 
+#' @export
+store_exist_object.tar_aws <- function(store, name = NULL) {
+  path <- store$file$path
+  aws_s3_exists(
+    key = store_aws_key(path),
+    bucket = store_aws_bucket(path),
+    region = store_aws_region(path),
+    endpoint = store_aws_endpoint(path),
+    version = store_aws_version(path)
+  )
+}
+
+#' @export
+store_delete_object.tar_aws <- function(store, name = NULL) {
+  path <- store$file$path
+  key <- store_aws_key(path)
+  bucket <- store_aws_bucket(path)
+  region <- store_aws_region(path)
+  endpoint <- store_aws_endpoint(path)
+  version <- store_aws_version(path)
+  message <- paste(
+    "could not delete target %s from AWS bucket %s key %s.",
+    "Either delete the object manually in the AWS web console",
+    "or call tar_invalidate(%s) to prevent the targets package",
+    "from trying to delete it.\nMessage: "
+  )
+  message <- sprintf(message, name, bucket, key, name)
+  tryCatch(
+    aws_s3_delete(
+      key = key,
+      bucket =  bucket,
+      region = region,
+      endpoint = endpoint,
+      version = version
+    ),
+    error = function(condition) {
+      tar_throw_validate(message, conditionMessage(condition))
+    }
+  )
+}
+
 #' @export
 store_upload_object.tar_aws <- function(store) {
   key <- store_aws_key(store$file$path)
@@ -112,6 +189,7 @@ store_upload_object.tar_aws <- function(store) {
       key = key,
       bucket = store_aws_bucket(store$file$path),
       region = store_aws_region(store$file$path),
+      endpoint = store_aws_endpoint(store$file$path),
       metadata = list("targets-hash" = store$file$hash),
       part_size = store$resources$aws$part_size %|||% (5 * (2 ^ 20))
     ),
@@ -138,6 +216,7 @@ store_has_correct_hash.tar_aws <- function(store) {
   path <- store$file$path
   bucket <- store_aws_bucket(path)
   region <- store_aws_region(path)
+  endpoint <- store_aws_endpoint(path)
   key <- store_aws_key(path)
   version <- store_aws_version(path)
   if_any(
@@ -145,6 +224,7 @@ store_has_correct_hash.tar_aws <- function(store) {
       key = key,
       bucket = bucket,
       region = region,
+      endpoint = endpoint,
       version = version
     ),
     identical(
@@ -152,6 +232,7 @@ store_has_correct_hash.tar_aws <- function(store) {
         key = key,
         bucket = bucket,
         region = region,
+        endpoint = endpoint,
         version = version
       ),
       store$file$hash
@@ -160,11 +241,12 @@ store_has_correct_hash.tar_aws <- function(store) {
   )
 }
 
-store_aws_hash <- function(key, bucket, region, version) {
+store_aws_hash <- function(key, bucket, region, endpoint, version) {
   head <- aws_s3_head(
     key = key,
     bucket = bucket,
     region = region,
+    endpoint = endpoint,
     version = version
   )
   head$Metadata[["targets-hash"]]
