@@ -88,7 +88,9 @@ tar_make <- function(
     callr_function = callr_function,
     callr_arguments = callr_arguments,
     envir = envir,
-    script = script
+    script = script,
+    store = store,
+    fun = "tar_make"
   )
   invisible(out)
 }
