@@ -87,7 +87,9 @@ tar_outdated <- function(
     callr_function = callr_function,
     callr_arguments = callr_arguments,
     envir = envir,
-    script = script
+    script = script,
+    store = store,
+    fun = "tar_outdated"
   )
 }
 
