@@ -5,13 +5,15 @@ tar_test("empty resources", {
 tar_test("populated resources", {
   out <- tar_resources(
     aws = resources_aws_init(),
+    gcp = resources_gcp_init(),
     clustermq = resources_clustermq_init(
       template = list(a = 1, n_cores = 123)
     )
   )
   expect_true(is.list(out))
-  expect_equal(sort(names(out)), sort(c("aws", "clustermq")))
+  expect_equal(sort(names(out)), sort(c("aws", "clustermq", "gcp")))
   expect_true(inherits(out$aws, "tar_resources_aws"))
+  expect_true(inherits(out$gcp, "tar_resources_gcp"))
   expect_true(inherits(out$clustermq, "tar_resources_clustermq"))
 })
 
